
# scrnatools

Helper methods for scRNAseq processing using scanpy + scVI

# To install from github:
```
git clone https://github.com/ntranoslab/scrnatools-git.git
cd sc-rna-tools-git
pip install -e scrnatools # allows live editing of source files
```

# To install from PyPI:
```
pip install scrnatools
```

# Usage:

scrnatools provides helper plotting and analysis functions built on top of the scanpy and scVI packages to perform common tasks in scRNA-seq analysis pipelines. Extensive description of general best practices and detailed default pipeline examples can be found in the scanpy and scvi-tools documentation. For an example walkthrough of a typical scRNA-seq pipeline and the added functionality provided by scrnatools see the jupyter notebooks provided at https://github.com/j-germino/scrnatools-git/tree/main/examples. These can be uploaded to Google drive and run within a Google colab environemnt, using a GPU session.

# API:

API documentation is available at: https://scrnatools-git.readthedocs.io/en/latest/
